@@ -13,7 +13,7 @@ APP_FOLDER=None
 def make_exec(path):
     "make a file executable"
     mode = os.stat(path)
-    os.chmod(path, mode | stat.S_IXOTH | stat.S_IEXEC | stat.S_IXGRP)
+    os.chmod(path, mode + (stat.S_IXOTH | stat.S_IEXEC | stat.S_IXGRP))
 
 def make_structure(archive,root, name, is_project=True):
     archive['name'] = archive['name'].replace("$project_name",name)
